baseObjects.QueryStore

|  | ## Cheshire3 Object Model: Class QueryStore

Module baseObjects :: Class QueryStore

## Class QueryStore
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
                  ObjectStore --+
                                |
                               QueryStore

Known Subclasses:
  queryStore.SimpleQueryStore

An interface to persistent storage for Queries.
Instance Methods

create_query(self, session, query=None) Create a new query in the store.
delete_query(self, session, id) Delete a query from the store.
fetch_query(self, session, id) Fetch a query from the store.
fetch_queryList(self, session, req) Fetch a list of identifiers associated with queries in the store.
store_query(self, session, object) Store a query, potentially overwriting an existing copy.
Inherited from `ObjectStore`: `create_object`, `delete_object`, `fetch_object`, `store_object` Inherited from `configParser.C3Object`: `__init__`, `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### create_query(self, session, query=None) | source code
Create a new query in the store.

### delete_query(self, session, id) | source code
Delete a query from the store.

### fetch_query(self, session, id) | source code
Fetch a query from the store.

### fetch_queryList(self, session, req) | source code
Fetch a list of identifiers associated with queries in the store.

### store_query(self, session, object) | source code
Store a query, potentially overwriting an existing copy.